@@ -2,8 +2,8 @@ import operator
 import six
 import functools
 from future.utils import with_metaclass
-from vaex.dataset import expression_namespace
-from vaex.dataset import default_shape, _ensure_strings_from_expressions
+from vaex.functions import expression_namespace
+from vaex.utils import _ensure_strings_from_expressions, _ensure_string_from_expression
 import numpy as np
 import vaex.serialize
 import base64
@@ -14,6 +14,9 @@ try:
 except ImportError:
     from io import BytesIO as StringIO
 
+# TODO: repeated from dataframe.py
+default_shape = 128
+
 _binary_ops = [
     dict(code="+", name='add', op=operator.add),
     dict(code="in", name='contains', op=operator.contains),
@@ -126,10 +129,18 @@ class DateTime(object):
     def dayofweek(self):
         return self.expression.ds.func.dt_dayofweek(self.expression)
 
+    @property
+    def dayofyear(self):
+        return self.expression.ds.func.dt_dayofyear(self.expression)
+
     @property
     def hour(self):
         return self.expression.ds.func.dt_hour(self.expression)
 
+    @property
+    def weekofyear(self):
+        return self.expression.ds.func.dt_weekofyear(self.expression)
+
 class StringOperations(object):
     def __init__(self, expression):
         self.expression = expression
@@ -161,7 +172,7 @@ class Expression(with_metaclass(Meta)):
         return self.ds.dtype(self.expression)
 
     def derivative(self, var, simplify=True):
-        var = vaex.dataset._ensure_string_from_expression(var)
+        var = _ensure_string_from_expression(var)
         return self.__class__(self, expresso.derivative(self.expression, var, simplify=simplify))
 
     def expand(self, stop=[]):
@@ -268,8 +279,11 @@ class Expression(with_metaclass(Meta)):
     def evaluate(self, i1=None, i2=None, out=None, selection=None):
         return self.ds.evaluate(self, i1, i2, out=out, selection=selection)
 
-    # def fillna(self, value, fill_nan=True, fill_masked=True):
-    #     return self.ds.func.fillna(self, value, fill_nan=fill_nan, fill_masked=fill_masked)
+    # TODO: it is not so elegant we need to have a custom version of this
+    # it now also misses the docstring, reconsider how the the meta class auto
+    # adds this method
+    def fillna(self, value, fill_nan=True, fill_masked=True):
+        return self.ds.func.fillna(self, value=value, fill_nan=fill_nan, fill_masked=fill_masked)
 
     def clip(self, lower=None, upper=None):
         return self.ds.func.clip(self, lower, upper)
@@ -295,37 +309,48 @@ class Expression(with_metaclass(Meta)):
         function = self.ds.add_function('_jit', f, unique=True)
         return function(*arguments)
 
-    def jit_pythran(self):
-        import pythran
-        import imp
-        import hashlib
-        # self._import_all(module)
-        names = []
-        funcs = set(vaex.dataset.expression_namespace.keys())
-        expression = self.expression
-        if expression in self.ds.virtual_columns:
-            expression = self.ds.virtual_columns[self.expression]
-        all_vars = self.ds.get_column_names(virtual=True, strings=True, hidden=True) + list(self.ds.variables.keys())
-        vaex.expresso.validate_expression(expression, all_vars, funcs, names)
-        names = list(set(names))
-        types = ", ".join(str(self.ds.dtype(name)) + "[]" for name in names)
-        argstring = ", ".join(names)
-        code = '''
+    def jit_pythran(self, verbose=False):
+        import logging
+        logger = logging.getLogger('pythran')
+        log_level = logger.getEffectiveLevel()
+        try:
+            if not verbose:
+                logger.setLevel(logging.ERROR)
+            import pythran
+            import imp
+            import hashlib
+            # self._import_all(module)
+            names = []
+            funcs = set(vaex.dataset.expression_namespace.keys())
+            expression = self.expression
+            if expression in self.ds.virtual_columns:
+                expression = self.ds.virtual_columns[self.expression]
+            all_vars = self.ds.get_column_names(virtual=True, strings=True, hidden=True) + list(self.ds.variables.keys())
+            vaex.expresso.validate_expression(expression, all_vars, funcs, names)
+            names = list(set(names))
+            types = ", ".join(str(self.ds.dtype(name)) + "[]" for name in names)
+            argstring = ", ".join(names)
+            code = '''
 from numpy import *
 #pythran export f({2})
 def f({0}):
     return {1}'''.format(argstring, expression, types)
-        print(code)
-        m = hashlib.md5()
-        m.update(code.encode('utf-8'))
-        module_name = "pythranized_" + m.hexdigest()
-        print(m.hexdigest())
-        module_path = pythran.compile_pythrancode(module_name, code, extra_compile_args=["-DBOOST_SIMD", "-march=native"])
-        module = imp.load_dynamic(module_name, module_path)
-        function_name = "f_" + m.hexdigest()
-        vaex.dataset.expression_namespace[function_name] = module.f
+            if verbose:
+                print("generated code")
+                print(code)
+            m = hashlib.md5()
+            m.update(code.encode('utf-8'))
+            module_name = "pythranized_" + m.hexdigest()
+            # print(m.hexdigest())
+            module_path = pythran.compile_pythrancode(module_name, code, extra_compile_args=["-DBOOST_SIMD", "-march=native"] + [] if verbose else ["-w"])
 
-        return Expression(self.ds, "{0}({1})".format(function_name, argstring))
+            module = imp.load_dynamic(module_name, module_path)
+            function_name = "f_" + m.hexdigest()
+            vaex.dataset.expression_namespace[function_name] = module.f
+
+            return Expression(self.ds, "{0}({1})".format(function_name, argstring))
+        finally:
+                logger.setLevel(log_level)
 
     def _rename(self, old, new):
         def translate(id):
@@ -443,8 +468,8 @@ class Function(object):
     def __init__(self, dataset, name, f):
         self.dataset = dataset
         self.name = name
-        # if not serializable, assume we can use pickle
-        if not isinstance(f, FunctionSerializable):
+
+        if not vaex.serialize.can_serialize(f): # if not serializable, assume we can use pickle
             f = FunctionSerializablePickle(f)
         self.f = f
 
